@@ -33,7 +33,8 @@ class PyprojectToml:
 
     def get_dependencies(self, *, dev: bool, parser: Callable[[str], str]):
         deps = self.dependencies if not dev else self.dev_dependencies
-        return f"{get_python_version()}\n" + "\n".join(parser(item) for item in deps)
+        res = "\n".join(parser(item) for item in deps) 
+        return (f"{get_python_version()}\n" + res) if not dev else res
 
     def get_optional_dependencies(self, parser: Callable[[str], str]):
         return "\n" + "\n".join(parser(item) for item in self._optional_dependencies)
